@@ -45,7 +45,8 @@ class CatGenerator(object):
     def MakeCat(self, OutputCatFile, PathToInf2CatTool=None):
         # Find Inf2Cat tool
         if(PathToInf2CatTool is None):
-            PathToInf2CatTool = os.path.join(os.getenv("ProgramFiles(x86)"), "Windows Kits", "10", "bin", "x86", "Inf2Cat.exe")
+            PathToInf2CatTool = os.path.join(os.getenv("ProgramFiles(x86)"), "Windows Kits", "10",
+                                             "bin", "x86", "Inf2Cat.exe")
             if not os.path.exists(PathToInf2CatTool):
                 logging.debug("Windows Kit 10 not Found....trying 8.1")
                 # Try 8.1 kit
@@ -53,7 +54,8 @@ class CatGenerator(object):
 
         # check if exists
         if not os.path.exists(PathToInf2CatTool):
-            raise Exception("Can't find Inf2Cat on this machine.  Please install the Windows 10 WDK - https://developer.microsoft.com/en-us/windows/hardware/windows-driver-kit")
+            raise Exception("Can't find Inf2Cat on this machine.  Please install the Windows 10 WDK - "
+                            "https://developer.microsoft.com/en-us/windows/hardware/windows-driver-kit")
 
         # Adjust for spaces in the path (when calling the command).
         if " " in PathToInf2CatTool:
