@@ -91,16 +91,20 @@ def reader(filepath, outstream, stream):
 
 
 def GetNugetCmd():
-    file = "nuget.exe"
+    file = "NuGet.exe"
     cmd = []
     if (os.name == "posix"):
         cmd += ["mono"]
+        found = False
         for env_var in os.getenv("PATH").split(os.pathsep):
-            env_var = os.path.normpath(env_var)
-            if os.path.isfile(os.path.join(env_var, file)):
-                file = "\"" + os.path.join(env_var, file) + "\""
-                logging.debug("File was found on the path: %s" % file)
+            env_var = os.path.join(os.path.normpath(env_var), file)
+            if os.path.isfile(env_var):
+                file = '"' + env_var + '"'
+                logging.info("File was found on the path: %s" % file)
+                found = True
                 break
+        if not found:
+            raise Exception("NuGet.exe not found on path")
     cmd += [file]
     return cmd
 
@@ -186,16 +190,19 @@ def RunPythonScript(pythonfile, params, capture=True, workingdir=None, outfile=N
                 logging.debug("Python Script was found on the path: %s" % pythonfile)
                 break
     params = pythonfile + " " + params
-    return RunCmd(sys.executable, params, capture=capture, workingdir=workingdir, outfile=outfile, outstream=outstream, environ=environ)
+    return RunCmd(sys.executable, params, capture=capture, workingdir=workingdir, outfile=outfile,
+                  outstream=outstream, environ=environ)
 ####
 # Locally Sign input file using Windows SDK signtool.  This will use a local Pfx file.
-# WARNING!!! : This should not be used for production signing as that process should follow stronger security practices (HSM / smart cards / etc)
+# WARNING!!! : This should not be used for production signing as that process should follow stronger
+#               security practices (HSM / smart cards / etc)
 #
 #  Signing is in format specified by UEFI authentacted variables
 ####
 
 
-def DetachedSignWithSignTool(SignToolPath, ToSignFilePath, SignatureOutputFile, PfxFilePath, PfxPass=None, Oid="1.2.840.113549.1.7.2", Eku=None):
+def DetachedSignWithSignTool(SignToolPath, ToSignFilePath, SignatureOutputFile, PfxFilePath,
+                             PfxPass=None, Oid="1.2.840.113549.1.7.2", Eku=None):
 
     # check signtool path
     if not os.path.exists(SignToolPath):
@@ -208,9 +215,11 @@ def DetachedSignWithSignTool(SignToolPath, ToSignFilePath, SignatureOutputFile,
 
     OutputDir = os.path.dirname(SignatureOutputFile)
     # Signtool docs https://docs.microsoft.com/en-us/dotnet/framework/tools/signtool-exe
-    # Signtool parameters from https://docs.microsoft.com/en-us/windows-hardware/manufacture/desktop/secure-boot-key-generation-and-signing-using-hsm--example
+    # Signtool parameters from
+    #   https://docs.microsoft.com/en-us/windows-hardware/manufacture/desktop/secure-boot-key-generation-and-signing-using-hsm--example  # noqa: E501
     # Search for "Secure Boot Key Generation and Signing Using HSM"
-    params = 'sign /fd sha256 /p7ce DetachedSignedData /p7co ' + Oid + ' /p7 "' + OutputDir + '" /f "' + PfxFilePath + '"'
+    params = 'sign /fd sha256 /p7ce DetachedSignedData /p7co ' + Oid + ' /p7 "' + \
+             OutputDir + '" /f "' + PfxFilePath + '"'
     if Eku is not None:
         params += ' /u ' + Eku
     if PfxPass is not None:
@@ -230,7 +239,8 @@ def DetachedSignWithSignTool(SignToolPath, ToSignFilePath, SignatureOutputFile,
 
 ####
 # Locally Sign input file using Windows SDK signtool.  This will use a local Pfx file.
-# WARNING!!! : This should not be used for production signing as that process should follow stronger security practices (HSM / smart cards / etc)
+# WARNING!!! : This should not be used for production signing as that process should follow
+#              stronger security practices (HSM / smart cards / etc)
 #
 #  Signing is catalog format which is an attached signature
 ####
